@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -258,7 +254,7 @@ public class LocaleNames_it extends OpenListResourceBundle {
             { "ER", "Eritrea" },
             { "ES", "Spagna" },
             { "ET", "Etiopia" },
-            { "EU", "Unione Europea" },
+            { "EU", "Unione europea" },
             { "elx", "elamitico" },
             { "type.ca.gregorian", "Calendario gregoriano" },
             { "EZ", "Eurozona" },
@@ -308,6 +304,7 @@ public class LocaleNames_it extends OpenListResourceBundle {
             { "GU", "Guam" },
             { "pdc", "tedesco della Pennsylvania" },
             { "GW", "Guinea-Bissau" },
+            { "rhg", "rohingya" },
             { "tli", "tlingit" },
             { "tlh", "klingon" },
             { "Talu", "tai lue" },
@@ -751,10 +748,11 @@ public class LocaleNames_it extends OpenListResourceBundle {
             { "Limb", "limbu" },
             { "sad", "sandawe" },
             { "type.nu.roman", "Numeri romani" },
-            { "sah", "yakut" },
+            { "sah", "sacha" },
             { "type.nu.shrd", "Cifre sharada" },
             { "ltg", "letgallo" },
             { "sam", "aramaico samaritano" },
+            { "Aghb", "albanese caucasico" },
             { "%%SCOUSE", "scouse" },
             { "saq", "samburu" },
             { "sas", "sasak" },
@@ -848,7 +846,7 @@ public class LocaleNames_it extends OpenListResourceBundle {
             { "Orya", "oriya" },
             { "cr", "cree" },
             { "cs", "ceco" },
-            { "cu", "slavo della Chiesa" },
+            { "cu", "slavo ecclesiastico" },
             { "yrl", "nheengatu" },
             { "cv", "ciuvascio" },
             { "cy", "gallese" },
@@ -888,7 +886,7 @@ public class LocaleNames_it extends OpenListResourceBundle {
             { "lzz", "laz" },
             { "es", "spagnolo" },
             { "et", "estone" },
-            { "Hanb", "hanb" },
+            { "Hanb", "han, bopomofo" },
             { "eu", "basco" },
             { "Buhd", "buhid" },
             { "Hang", "hangul" },
@@ -935,7 +933,7 @@ public class LocaleNames_it extends OpenListResourceBundle {
             { "bin", "bini" },
             { "ho", "hiri motu" },
             { "hr", "croato" },
-            { "ht", "haitiano" },
+            { "ht", "creolo haitiano" },
             { "hu", "ungherese" },
             { "hy", metaValue_hy },
             { "hz", "herero" },
