@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -147,11 +147,11 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
                "",
             };
         final String[] Peru = new String[] {
-               "Peru Standard Time",
+               "\u00c0k\u00f3k\u00f2 \u00c0f\u1eb9nuk\u00f2 P\u00e9r\u00f9",
                "",
-               "Peru Summer Time",
+               "\u00c0k\u00f3k\u00f2 Ooru P\u00e9r\u00f9",
                "",
-               "Peru Time",
+               "\u00c0k\u00f3k\u00f2 P\u00e9r\u00f9",
                "",
             };
         final String[] Truk = new String[] {
@@ -171,11 +171,11 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
                "",
             };
         final String[] Chile = new String[] {
-               "Chile Standard Time",
+               "\u00c0k\u00f3k\u00f2 \u00c0f\u1eb9nuk\u00f2 \u1e62\u00edl\u00e8",
                "",
-               "Chile Summer Time",
+               "\u00c0k\u00f3k\u00f2 Oru \u1e62\u00edl\u00e8",
                "",
-               "Chile Time",
+               "\u00c0k\u00f3k\u00f2 \u1e62\u00edl\u00e8",
                "",
             };
         final String[] China = new String[] {
@@ -274,28 +274,36 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
                "Tonga Time",
                "",
             };
+        final String[] Yukon = new String[] {
+               "\u00c0k\u00f3k\u00f2 Y\u00fak\u1ecd\u0301n\u00ec",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Alaska = new String[] {
-               "Alaska Standard Time",
+               "\u00c0k\u00f3k\u00f2 \u00c0f\u1eb9nuk\u00f2 Al\u00e1s\u00edk\u00e0",
                "",
-               "Alaska Daylight Time",
+               "\u00c0k\u00f3k\u00f2 \u00ccy\u00e1l\u1eb9\u0300ta Al\u00e1s\u00edk\u00e0",
                "",
-               "Alaska Time",
+               "\u00c0k\u00f3k\u00f2 Al\u00e1s\u00edk\u00e0",
                "",
             };
         final String[] Amazon = new String[] {
-               "Amazon Standard Time",
+               "\u00c0k\u00f3k\u00f2 Af\u1eb9nuk\u00f2 Am\u00e1s\u1ecd\u0301n\u00ec",
                "",
-               "Amazon Summer Time",
+               "\u00c0k\u00f3k\u00f2 Oru Am\u00e1s\u1ecd\u0301n\u00ec",
                "",
-               "Amazon Time",
+               "\u00c0k\u00f3k\u00f2 Am\u00e1s\u1ecd\u0301n\u00ec",
                "",
             };
         final String[] Azores = new String[] {
-               "Azores Standard Time",
+               "\u00c0k\u00f3k\u00f2 \u00c0f\u1eb9nuk\u00f2 \u00c1s\u1ecd\u0301s\u00ec",
                "",
-               "Azores Summer Time",
+               "\u00c0k\u00f3k\u00f2 Ooru \u00c1s\u1ecd\u0301s\u00ec",
                "",
-               "Azores Time",
+               "\u00c0k\u00f3k\u00f2 \u00c1s\u1ecd\u0301s\u00ec",
                "",
             };
         final String[] Bhutan = new String[] {
@@ -323,7 +331,7 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
                "",
             };
         final String[] Guyana = new String[] {
-               "Guyana Time",
+               "\u00c0k\u00f3k\u00f2 G\u00fay\u00e0n\u00e0",
                "",
                "",
                "",
@@ -475,11 +483,11 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
                "",
             };
         final String[] Irkutsk = new String[] {
-               "Irkutsk Standard Time",
+               "\u00c0k\u00f3k\u00f2 \u00c0f\u1eb9nuk\u00f2 \u00cdk\u00f3s\u00edk\u00ec",
                "",
-               "Irkutsk Summer Time",
+               "\u00c0k\u00f3k\u00f2 S\u1ecdm\u00e0 \u00cdk\u00fas\u00edk\u00ec",
                "",
-               "Irkutsk Time",
+               "\u00c0k\u00f3k\u00f2 \u00cdk\u00f3s\u00edk\u00ec",
                "",
             };
         final String[] Magadan = new String[] {
@@ -515,7 +523,7 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
                "",
             };
         final String[] Reunion = new String[] {
-               "R\u00e9union Time",
+               "\u00c0k\u00f3k\u00f2 R\u1eb9\u0301y\u00fan\u00ed\u1ecd\u0301n\u00ec",
                "",
                "",
                "",
@@ -547,7 +555,7 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
                "",
             };
         final String[] Uruguay = new String[] {
-               "Uruguay Standard Time",
+               "\u00c0k\u00f3k\u00f2 \u00c0f\u1eb9nuk\u00f2 \u00dar\u00fag\u00faw\u00e8",
                "",
                "Aago Soma Uruguay",
                "",
@@ -603,11 +611,11 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
                "",
             };
         final String[] Falkland = new String[] {
-               "Falkland Islands Standard Time",
+               "\u00c0k\u00f3k\u00f2 \u00c0f\u1eb9nuk\u00f2 Et\u00edkun F\u00f3k\u00edl\u00e1nd\u00ec",
                "",
-               "Falkland Islands Summer Time",
+               "\u00c0k\u00f3k\u00f2 Ooru Et\u00edkun F\u00f3k\u00edl\u00e1nd\u00ec",
                "",
-               "Falkland Islands Time",
+               "\u00c0k\u00f3k\u00f2 F\u00f3k\u00edl\u00e1nd\u00ec",
                "",
             };
         final String[] Malaysia = new String[] {
@@ -643,11 +651,11 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
                "",
             };
         final String[] Paraguay = new String[] {
-               "Paraguay Standard Time",
+               "\u00c0k\u00f3k\u00f2 \u00c0f\u1eb9nuk\u00f2 P\u00e1r\u00e1g\u00faw\u00e8",
                "",
-               "Paraguay Summer Time",
+               "\u00c0k\u00f3k\u00f2 Ooru P\u00e1r\u00e1g\u00faw\u00e8",
                "",
-               "Paraguay Time",
+               "\u00c0k\u00f3k\u00f2 P\u00e1r\u00e1g\u00faw\u00e8",
                "",
             };
         final String[] Pitcairn = new String[] {
@@ -667,7 +675,7 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
                "",
             };
         final String[] Suriname = new String[] {
-               "Suriname Time",
+               "\u00c0k\u00f3k\u00f2 S\u00far\u00edn\u00e1m\u00f9",
                "",
                "",
                "",
@@ -739,11 +747,11 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
                "",
             };
         final String[] Mauritius = new String[] {
-               "Mauritius Standard Time",
+               "\u00c0k\u00f3k\u00f2 \u00c0f\u1eb9nuk\u00f2 M\u00e1r\u00ed\u1e63\u00fa\u1e63\u00ec",
                "",
-               "Mauritius Summer Time",
+               "\u00c0k\u00f3k\u00f2 Ooru M\u00e1r\u00ed\u1e63\u00fa\u1e63\u00ec",
                "",
-               "Mauritius Time",
+               "\u00c0k\u00f3k\u00f2 M\u00e1r\u00ed\u1e63\u00fa\u1e63\u00ec",
                "",
             };
         final String[] Singapore = new String[] {
@@ -787,11 +795,11 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
                "",
             };
         final String[] Cape_Verde = new String[] {
-               "Cape Verde Standard Time",
+               "\u00c0k\u00f3k\u00f2 \u00c0f\u1eb9nuk\u00f2 K\u00e9p\u00fa F\u00e1\u00e0d\u00ec",
                "",
-               "Cape Verde Summer Time",
+               "\u00c0k\u00f3k\u00f2 S\u1ecd\u0301m\u00e0 K\u00e9p\u00fa F\u00e1\u00e0d\u00ec",
                "",
-               "Cape Verde Time",
+               "\u00c0k\u00f3k\u00f2 K\u00e9p\u00fa F\u00e1\u00e0d\u00ec",
                "",
             };
         final String[] East_Timor = new String[] {
@@ -803,7 +811,7 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
                "",
             };
         final String[] Seychelles = new String[] {
-               "Seychelles Time",
+               "\u00c0k\u00f3k\u00f2 S\u00e8\u1e63\u1eb9\u0301\u1eb9\u0300l\u00ec",
                "",
                "",
                "",
@@ -875,7 +883,7 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
                "",
             };
         final String[] Indian_Ocean = new String[] {
-               "Indian Ocean Time",
+               "\u00c0k\u00f3k\u00f2 Et\u00edkun \u00cdnd\u00ed\u00e0",
                "",
                "",
                "",
@@ -907,7 +915,7 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
                "",
             };
         final String[] French_Guiana = new String[] {
-               "French Guiana Time",
+               "\u00c0k\u00f3k\u00f2 G\u00fay\u00e1n\u00e0 F\u00e1r\u00e1ns\u00e8",
                "",
                "",
                "",
@@ -923,7 +931,7 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
                "",
             };
         final String[] South_Georgia = new String[] {
-               "South Georgia Time",
+               "\u00c0k\u00f3k\u00f2 G\u00fas\u00f9 J\u1ecd\u0301j\u00ed\u00e0",
                "",
                "",
                "",
@@ -939,7 +947,7 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
                "",
             };
         final String[] Africa_Central = new String[] {
-               "Central Africa Time",
+               "\u00c0k\u00f3k\u00f2 \u00c0\u00e1r\u00edn Af\u00edrik\u00e0",
                "",
                "",
                "",
@@ -947,7 +955,7 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
                "",
             };
         final String[] Africa_Eastern = new String[] {
-               "East Africa Time",
+               "\u00c0k\u00f3k\u00f2 \u00ccl\u00e0-O\u00f2r\u00f9n Af\u00edrik\u00e0",
                "",
                "",
                "",
@@ -955,11 +963,11 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
                "",
             };
         final String[] Africa_Western = new String[] {
-               "West Africa Standard Time",
+               "\u00c0k\u00f3k\u00f2 \u00ccw\u1ecd\u0300-O\u00f2r\u00f9n \u00c0f\u1eb9nuk\u00f2 Af\u00edrik\u00e0",
                "",
-               "West Africa Summer Time",
+               "\u00c0k\u00f3k\u00f2 \u00ccw\u1ecd\u0300-O\u00f2r\u00f9n Ooru Af\u00edrik\u00e0",
                "",
-               "West Africa Time",
+               "\u00c0k\u00f3k\u00f2 \u00ccw\u1ecd\u0300-O\u00f2r\u00f9n Af\u00edrik\u00e0",
                "",
             };
         final String[] DumontDUrville = new String[] {
@@ -1035,7 +1043,7 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
                "",
             };
         final String[] French_Southern = new String[] {
-               "French Southern & Antarctic Time",
+               "\u00c0k\u00f3k\u00f2 G\u00fas\u00f9 F\u00e1rans\u00e9 \u00e0ti \u00c0nt\u00e1t\u00ed\u00eck\u00ec",
                "",
                "",
                "",
@@ -1404,7 +1412,7 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Mountain },
+            { "America/Dawson", Yukon },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1607,7 +1615,7 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
             { "America/Montserrat", Atlantic },
             { "America/Paramaribo", Suriname },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Mountain },
+            { "America/Whitehorse", Yukon },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
@@ -1650,7 +1658,6 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
             { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
-            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
